@@ -1,7 +1,6 @@
-package Pcore::API::Whois v0.3.0;
+package Pcore::API::Whois v0.3.1;
 
 use Pcore -dist, -class;
-use Pcore::Handle;
 use Pcore::API::Whois::Server;
 use Pcore::API::Whois::Response qw[:CONST];
 use Net::Whois::Raw::Data qw[];
@@ -56,7 +55,7 @@ sub _build_cfg ($self) {
 sub _build_dbh ($self) {
     return if !$self->cache;
 
-    my $dbh = Pcore::Handle->new( 'sqlite:' . $self->cache );
+    my $dbh = P->handle( 'sqlite:' . $self->cache );
 
     # DDL
     my $ddl = $dbh->ddl;
@@ -294,11 +293,11 @@ sub _request ( $self, $server, $query, $cb ) {
 ## +------+----------------------+----------------------------------------------------------------------------------------------------------------+
 ## | Sev. | Lines                | Policy                                                                                                         |
 ## |======+======================+================================================================================================================|
-## |    3 | 26, 36               | References::ProhibitDoubleSigils - Double-sigil dereference                                                    |
+## |    3 | 25, 35               | References::ProhibitDoubleSigils - Double-sigil dereference                                                    |
 ## |------+----------------------+----------------------------------------------------------------------------------------------------------------|
-## |    3 | 82                   | Subroutines::ProhibitExcessComplexity - Subroutine "search" with high complexity score (31)                    |
+## |    3 | 81                   | Subroutines::ProhibitExcessComplexity - Subroutine "search" with high complexity score (31)                    |
 ## |------+----------------------+----------------------------------------------------------------------------------------------------------------|
-## |    1 | 40                   | ValuesAndExpressions::RequireInterpolationOfMetachars - String *may* require interpolation                     |
+## |    1 | 39                   | ValuesAndExpressions::RequireInterpolationOfMetachars - String *may* require interpolation                     |
 ## +------+----------------------+----------------------------------------------------------------------------------------------------------------+
 ##
 ## -----SOURCE FILTER LOG END-----
